==> auto-ui-2.1.25.tgz: package/es/at-nav/index.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import cn from 'classnames';
import * as React from 'react';
import './style.scss';
var AtNav = function (props) {
    var active = props.active, className = props.className, otherProps = __rest(props, ["active", "className"]);
    return (React.createElement("nav", __assign({}, otherProps, { className: cn('x-at-nav', className) }),
        active === 'index' ? (React.createElement("p", { className: "x-at-navitem x-at-navitem__index" },
            React.createElement("i", null),
            React.createElement("small", null, "\u9996\u9875"))) : (React.createElement("a", { className: "x-at-navitem x-at-navitem__index", href: "/m/user/index" },
            React.createElement("i", null),
            React.createElement("small", null, "\u9996\u9875"))),
        active === 'order' ? (React.createElement("p", { className: "x-at-navitem x-at-navitem__order" },
            React.createElement("i", null),
            React.createElement("small", null, "\u884C\u7A0B"))) : (React.createElement("a", { className: "x-at-navitem x-at-navitem__order", href: "/m/order" },
            React.createElement("i", null),
            React.createElement("small", null, "\u884C\u7A0B"))),
        active === 'collection' ? (React.createElement("p", { className: "x-at-navitem x-at-navitem__collection" },
            React.createElement("i", null),
            React.createElement("small", null, "\u6536\u85CF"))) : (React.createElement("a", { className: "x-at-navitem x-at-navitem__collection", href: "/m/user/collection" },
            React.createElement("i", null),
            React.createElement("small", null, "\u6536\u85CF"))),
        active === 'user' ? (React.createElement("p", { className: "x-at-navitem x-at-navitem__user" },
            React.createElement("i", null),
            React.createElement("small", null, "\u6211\u7684"))) : (React.createElement("a", { className: "x-at-navitem x-at-navitem__user", href: "/m/user" },
            React.createElement("i", null),
            React.createElement("small", null, "\u6211\u7684")))));
};
export default AtNav;

==> auto-ui-2.1.28.tgz: package/es/at-nav/index.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) if (e.indexOf(p[i]) < 0)
            t[p[i]] = s[p[i]];
    return t;
};
import cn from 'classnames';
import * as React from 'react';
import './style.scss';
var AtNav = function (props) {
    var active = props.active, className = props.className, otherProps = __rest(props, ["active", "className"]);
    return (React.createElement("nav", __assign({}, otherProps, { className: cn('x-at-nav', className) }),
        active === 'index' ? (React.createElement("p", { className: "x-at-navitem x-at-navitem__index" },
            React.createElement("i", null),
            React.createElement("small", null, "\u9996\u9875"))) : (React.createElement("a", { className: "x-at-navitem x-at-navitem__index", href: "/m/user/index" },
            React.createElement("i", null),
            React.createElement("small", null, "\u9996\u9875"))),
        active === 'order' ? (React.createElement("p", { className: "x-at-navitem x-at-navitem__order" },
            React.createElement("i", null),
            React.createElement("small", null, "\u884C\u7A0B"))) : (React.createElement("a", { className: "x-at-navitem x-at-navitem__order", href: "/m/order" },
            React.createElement("i", null),
            React.createElement("small", null, "\u884C\u7A0B"))),
        active === 'collection' ? (React.createElement("p", { className: "x-at-navitem x-at-navitem__collection" },
            React.createElement("i", null),
            React.createElement("small", null, "\u6536\u85CF"))) : (React.createElement("a", { className: "x-at-navitem x-at-navitem__collection", href: "/m/user/collection" },
            React.createElement("i", null),
            React.createElement("small", null, "\u6536\u85CF"))),
        active === 'user' ? (React.createElement("p", { className: "x-at-navitem x-at-navitem__user" },
            React.createElement("i", null),
            React.createElement("small", null, "\u6211\u7684"))) : (React.createElement("a", { className: "x-at-navitem x-at-navitem__user", href: "/m/user" },
            React.createElement("i", null),
            React.createElement("small", null, "\u6211\u7684")))));
};
export default AtNav;
